{% extends "base.html" %}
{% load wagtailimages_tags i18n %}

{% block content %}
<div>
    <ul>
        {% for persona in persona_pages %}
          <li>
            {% if persona.image %}
              {% image persona.image width-75 as tmp_photo %}
              <img src="{{ tmp_photo.url }}" alt="{{ persona.image.title }}"/>
            {% endif %}
            <a href="{% url 'molo.usermetadata:set_persona' persona.id %}?next={{ next }}">{{ persona.title }}</a>
          </li>
        {% endfor %}
    </ul>
    <a href="{% url 'molo.usermetadata:skip_persona'%}?next={{ next }}">{% trans "Skip" %}</a>
</div>
{% endblock %}
